### Name: Dref
### Title: gnm ``plug-in'' Function to Fit Diagonal Reference Terms
### Aliases: Dref
### Keywords: models regression nonlinear

### ** Examples

### Examples from Clifford and Heath paper
### (Results differ slightly - possible transcription error in
### published data?)
set.seed(1)
data(voting)
## reconstruct counts voting Labour/non-Labour
count <- with(voting, percentage/100 * total)
yvar <- cbind(count, voting$total - count)

## fit diagonal reference model with constant weights
classMobility <- gnm(yvar ~ Nonlin(Dref(origin, destination)), 
                     family = binomial, data = voting)
prop.table(exp(coef(classMobility)[2:3]))

## create factors indicating movement in and out of salariat (class 1)
upward <- with(voting, origin != 1 & destination == 1)
downward <- with(voting, origin == 1 & destination != 1)

## fit separate weights for the "socially mobile" groups
socialMobility <- gnm(yvar ~ Nonlin(Dref(origin, destination,
                                         formula = ~ 1 + downward + upward)),
                      family = binomial, data = voting)
prop.table(exp(coef(socialMobility)[c(4, 7)] + coef(socialMobility)[c(2, 5)]))
prop.table(exp(coef(socialMobility)[c(3, 6)] + coef(socialMobility)[c(2, 5)]))
prop.table(exp(coef(socialMobility)[c(2, 5)]))

## fit separate weights for downwardly mobile groups only
downwardMobility <- gnm(yvar ~ Nonlin(Dref(origin, destination,
                                           formula = ~ 1 + downward)),
                        family = binomial, data = voting)
downwardMobility
prop.table(exp(coef(downwardMobility)[c(3, 5)] + 
               coef(downwardMobility)[c(2, 4)]))
               prop.table(exp(coef(downwardMobility)[c(2, 4)]))

## Not run:               
##D ### Examples from Van der Slik paper
##D ### For illustration only - data not publically available
##D ### Using data in data.frame named 'conformity', with variables
##D ### MCFM - mother's conformity score
##D ### FCFF - father's conformity score
##D ### MOPLM - a factor describing the mother's education with 7 levels
##D ### FOPLF - a factor describing the father's education with 7 levels
##D ### AGEM - mother's birth cohort
##D ### MRMM - mother's traditional role model
##D ### FRMF - father's traditional role model
##D ### MWORK - mother's employment
##D ### MFCM - mother's family conflict score
##D ### FFCF - father's family conflict score
##D 
##D set.seed(1)
##D 
##D ## Models for mothers' conformity score as specified in Figure 1
##D A <- gnm(MCFM ~ -1 + AGEM + MRMM + FRMF + MWORK + MFCM + 
##D          Nonlin(Dref(MOPLM, FOPLF)), family = gaussian, data = conformity,
##D          verbose = FALSE)
##D A
##D ## Call:
##D ## gnm(formula = MCFM ~ -1 + AGEM + MRMM + FRMF + MWORK + MFCM + 
##D ##     Nonlin(Dref(MOPLM, FOPLF)), family = gaussian, data = conformity,
##D ##     verbose = FALSE)
##D ##
##D ##
##D ## Coefficients:
##D ##                    AGEM                      MRMM                      FRMF  
##D ##                 0.06364                  -0.32425                  -0.25324  
##D ##                   MWORK                      MFCM  Dref(MOPLM, FOPLF).MOPLM  
##D ##                -0.06430                  -0.06043                   0.34389  
##D ## Dref(MOPLM, FOPLF).FOPLF      Dref(MOPLM, FOPLF).1      Dref(MOPLM, FOPLF).2  
##D ##                 0.65611                   4.95123                   4.86328  
##D ##     Dref(MOPLM, FOPLF).3      Dref(MOPLM, FOPLF).4      Dref(MOPLM, FOPLF).5  
##D ##                 4.86458                   4.72342                   4.43516  
##D ##     Dref(MOPLM, FOPLF).6      Dref(MOPLM, FOPLF).7  
##D ##                 4.18873                   4.43379  
##D ##
##D ## Deviance:            425.3389 
##D ## Pearson chi-squared: 425.3389 
##D ## Residual df:         576
##D 
##D prop.table(exp(coef(A)[6:7])) ## weights as in Table 4
##D ## Dref(MOPLM, FOPLF).MOPLM Dref(MOPLM, FOPLF).FOPLF 
##D ##               0.4225734                0.5774266
##D 
##D F <- gnm(MCFM ~ -1 + AGEM + MRMM + FRMF + MWORK + MFCM + 
##D          Nonlin(Dref(MOPLM, FOPLF, formula = ~1 + MFCM)), family = gaussian,
##D          data = conformity, verbose = FALSE)
##D F        
##D ## Call:
##D ## gnm(formula = MCFM ~ -1 + AGEM + MRMM + FRMF + MWORK + MFCM + 
##D ##     Nonlin(Dref(MOPLM, FOPLF, formula = ~1 + MFCM)), family = gaussian, 
##D ##     data = conformity, verbose = FALSE)
##D ##
##D ##
##D ## Coefficients:
##D ##                                                      AGEM  
##D ##                                                   0.05818  
##D ##                                                      MRMM  
##D ##                                                  -0.32701  
##D ##                                                      FRMF  
##D ##                                                  -0.25772  
##D ##                                                     MWORK  
##D ##                                                  -0.07847  
##D ##                                                      MFCM  
##D ##                                                  -0.01694  
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).MOPLM.(Intercept)  
##D ##                                                   1.03516  
##D ##        Dref(MOPLM, FOPLF, formula = ~1 + MFCM).MOPLM.MFCM  
##D ##                                                  -1.77703  
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).FOPLF.(Intercept)  
##D ##                                                  -0.03516  
##D ##        Dref(MOPLM, FOPLF, formula = ~1 + MFCM).FOPLF.MFCM  
##D ##                                                   2.77703  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).1  
##D ##                                                   4.82477  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).2  
##D ##                                                   4.88066  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).3  
##D ##                                                   4.83969  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).4  
##D ##                                                   4.74849  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).5  
##D ##                                                   4.42019  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).6  
##D ##                                                   4.17956  
##D ##                 Dref(MOPLM, FOPLF, formula = ~1 + MFCM).7  
##D ##                                                   4.40819  
##D ## 
##D ## Deviance:            420.9022 
##D ## Pearson chi-squared: 420.9022 
##D ## Residual df:         575
##D 
##D prop.table(exp(coef(F))[c(6,8)]) ## weights for MFCM = 0
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).MOPLM.(Intercept) 
##D ##                                                 0.7446585 
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).FOPLF.(Intercept) 
##D ##                                                 0.2553415 
##D prop.table(exp(coef(F)[c(7,9)] + coef(F)[c(6,8)])) ## weights for MFCM = 1
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).MOPLM.MFCM 
##D ##                                         0.02977851 
##D ## Dref(MOPLM, FOPLF, formula = ~1 + MFCM).FOPLF.MFCM 
##D ##                                         0.97022149 
## End(Not run)



