### Name: checkEstimable
### Title: Check Whether One or More Parameter Combinations in a gnm Model
###   are Identified
### Aliases: checkEstimable
### Keywords: models regression nonlinear

### ** Examples

data(yaish)
set.seed(1)

## Fit the "UNIDIFF" mobility model across education levels
unidiff <- gnm(Freq ~ educ:orig + educ:dest +
               Mult(Exp(educ), orig:dest), family = poisson,
               data = yaish)

## Check whether Mult1.Factor1.educ4 - Mult1.Factor1.educ5 is estimable
educ4.pos <- grep("Mult1.Factor1.educ4", names(coef(unidiff)))
checkEstimable(unidiff, c(rep(0, educ4.pos - 1), 1, -1,
                          rep(0, length(coef(unidiff)) - educ4.pos - 1)))
## should be TRUE

## Check whether Mult1.Factor1.educ4 is estimable
checkEstimable(unidiff, c(rep(0, educ4.pos - 1), 1, 0,
                          rep(0, length(coef(unidiff)) - educ4.pos - 1)))
## should be FALSE -- only *differences* are identified here



