### Name: gnm
### Title: Fitting Generalized Nonlinear Models
### Aliases: gnm
### Keywords: models regression nonlinear

### ** Examples

###  Analysis of a 4-way contingency table
set.seed(1)
data(cautres)
print(cautres)

##  Fit a "double UNIDIFF" model with the religion-vote and class-vote
##  interactions both modulated by nonnegative election-specific
##  multipliers.
doubleUnidiff <- gnm(Freq ~ election:vote + election:class:religion
                     + Mult(Exp(election - 1), religion:vote - 1) +
                     Mult(Exp(election - 1), class:vote - 1), family = poisson,
                     data = cautres)

##  Examine the multipliers of the class-vote log odds ratios
coefs.of.interest <- grep("Mult2.*election", names(coef(doubleUnidiff)))
coef(doubleUnidiff)[coefs.of.interest]
##  Mult2.Factor1.election1 Mult2.Factor1.election2 
##               -0.5724370               0.1092972 
##  Mult2.Factor1.election3 Mult2.Factor1.election4 
##               -0.1230682              -0.2105843

##  Re-parameterize by setting Mult2.Factor1.election4 to zero
getContrasts(doubleUnidiff, coefs.of.interest)
##                            estimate        se
##  Mult2.Factor1.election1 -0.3618399 0.2534762
##  Mult2.Factor1.election2  0.3198951 0.1320034
##  Mult2.Factor1.election3  0.0875308 0.1446842
##  Mult2.Factor1.election4  0.0000000 0.0000000

##  Same thing but with election 1 as reference category:
getContrasts(doubleUnidiff, rev(coefs.of.interest))
##                            estimate        se
##  Mult2.Factor1.election4  0.3618399 0.2534746
##  Mult2.Factor1.election3  0.4493707 0.2473524
##  Mult2.Factor1.election2  0.6817351 0.2401645
##  Mult2.Factor1.election1  0.0000000 0.0000000

##  Re-fit model with Mult2.Factor1.election1 set to zero
doubleUnidiffConstrained <-
    update(doubleUnidiff, constrain = coefs.of.interest[1])

##  Examine the multipliers of the class-vote log odds ratios
coef(doubleUnidiffConstrained)[coefs.of.interest]
##  ...as using 'getContrasts' (to 4 d.p.).



