### Name: wheat
### Title: Wheat Yields from Mexican Field Trials
### Aliases: wheat
### Keywords: datasets

### ** Examples

set.seed(1)
data(wheat)

##  Scale yields to reproduce analyses reported in Vargas et al (2001)
yield.scaled <- wheat$yield * sqrt(3/1000)

##  Reproduce (up to error caused by rounding) Table 1 of Vargas et al (2001)
aov(yield.scaled ~ year*tillage*summerCrop*manure*N, data = wheat)
treatment <- interaction(wheat$tillage, wheat$summerCrop, wheat$manure,
                         wheat$N, sep = "")
mainEffects <- glm(yield.scaled ~ year + treatment, family = gaussian,
                   data = wheat)
bilinear1 <- gnm(yield.scaled ~ year + treatment + Mult(year, treatment),
                 family = gaussian, data = wheat)
anova(mainEffects, bilinear1)
## Not run: 
##D     ## The next two take a lot of iterations to converge...
##D     bilinear2 <- gnm(yield.scaled ~ year + treatment +
##D                      Mult(year, treatment, multiplicity = 2),
##D                      family = gaussian, data = wheat)
##D     bilinear3 <- gnm(yield.scaled ~ year + treatment +
##D                      Mult(year, treatment, multiplicity = 3),
##D                      family = gaussian, data = wheat)
##D     anova(mainEffects, bilinear1, bilinear2, bilinear3)
## End(Not run)

##  Examine the extent to which, say, mTF explains the first bilinear term
bilinear1mTF <- gnm(yield.scaled ~ year + treatment + Mult(1 + mTF, treatment),
                    family = gaussian, data = wheat)
anova(mainEffects, bilinear1mTF, bilinear1)



